### Weather extra

setwd("U:/20160301_BH/20160803_Data&Papers/20171004_MENE_Weather") # set working directory
require(pacman) # loads pacman
p_load(tidyverse,haven,lubridate,glue) # loads tidyverse
mene <- read_sav("mene1_7_resp.SAV")

### investigating respondent file

glimpse(mene) # summarises mene - will need Interviewdata, year, and q1

# need just years one to four

fct_count(as.factor(mene$year)) # sample sizes look good
mene2 <- mene[which(mene$year<=4),] # selecting just years one to four

# extracting months with lubridate

mene2$month <- month(mene2$Interviewdate,label=T) # extracts montsh from Interview date
class(mene2$month) # ordered factor class
fct_count(mene2$month) # some differing sample sizes due to start/end dates of survey data collection periods

# creating a binary variable for visit in the last week versus not

mene2$v_lastweek <- NA
mene2$v_lastweek[which(mene2$q1=="0")] <- "No"
mene2$v_lastweek[which(mene2$q1>0)] <- "Yes"
mene2$v_lastweek <- factor(mene2$v_lastweek)
fct_count(mene2$v_lastweek)

# creating a table of counts and percentages of people visiting at least once in the past week by month of interview date and plotting this

gtable <- mene2 %>% group_by(month,v_lastweek) %>% summarise(n=n()) %>% mutate(perc=n/sum(n)*100) %>% filter(v_lastweek=="Yes") %>% ungroup()
plot1 <- ggplot(gtable,aes(x=month,y=perc,group=1)) + geom_point() + geom_line() + ylim(c(0,100)) + ylab("Percentage") + xlab("Month of interview")

# doing the same but for the whole sampling period as with old figure 2

mene2$years_to_glue <- NA
mene2$years_to_glue <- year(mene2$Interviewdate)
mene2$years_to_glue <- factor(mene2$years_to_glue)
fct_count(mene2$years_to_glue)

mene2$month_year <- NA
mene2$month_year <- mene2 %>% glue_data("{month} {years_to_glue}")
mene2$month_year <- factor(mene2$month_year,levels=c("Feb 2009", "Mar 2009","Apr 2009","May 2009","Jun 2009","Jul 2009","Aug 2009","Sep 2009","Oct 2009","Nov 2009","Dec 2009",
                                                     "Jan 2010","Feb 2010","Mar 2010","Apr 2010","May 2010","Jun 2010","Jul 2010","Aug 2010","Sep 2010","Oct 2010","Nov 2010","Dec 2010",
                                                     "Jan 2011","Feb 2011","Mar 2011","Apr 2011","May 2011","Jun 2011","Jul 2011","Aug 2011","Sep 2011","Oct 2011","Nov 2011","Dec 2011",
                                                     "Jan 2012","Feb 2012","Mar 2012","Apr 2012","May 2012","Jun 2012","Jul 2012","Aug 2012","Sep 2012","Oct 2012","Nov 2012","Dec 2012",
                                                     "Jan 2013","Feb 2013","Mar 2013","Apr 2013"))
fct_count(mene2$month_year)

gtable2 <- mene2 %>% group_by(month_year,v_lastweek) %>% summarise(n=n()) %>% mutate(perc=n/sum(n)*100) %>% filter(v_lastweek=="Yes") %>% ungroup()
plot2 <- ggplot(gtable2,aes(x=month_year,y=perc,group=1)) +
  geom_line(size=0.75) +
  scale_y_continuous(name="Percentage", limits=c(0,100)) +
  scale_x_discrete(breaks = levels(mene2$month_year)[c(T, rep(F, 3))]) +
  theme(axis.title.x=element_blank(), panel.background = element_blank(), panel.grid = element_blank(), panel.border = element_rect(fill=NA), axis.text.x=element_text(angle=45, hjust=1))
plot2

pdf(file=glue("Figure 2_NEW.pdf"),width=5,height=4)
plot2
dev.off()
dev.off()

###################### END OF SCRIPT ######################
